RocketCEA Wraps The NASA Fortran CEA Code And Provides Some Useful Tools — RocketCEA 1.0.5 documentation

# RocketCEA Wraps The NASA Fortran CEA Code And Provides Some Useful Tools

See the Code at: https://github.com/sonofeft/RocketCEA

See the Docs at: http://rocketcea.readthedocs.org/en/latest/

See PyPI page at:https://pypi.python.org/pypi/rocketcea

See NASA CEA HomePage at: https://www.grc.nasa.gov/WWW/CEAWeb/ceaHome.htm

RocketCEA makes direct calls to the NASA FORTRAN CEA code in “rocket” mode to calculate Isp, Cstar, Tcham etc. and provides tools to help determine useful mixture ratio range, optimum MR and more.

RocketCEA does not use the FORTRAN CEA2.f file directly.

Many modifications have been made in order to wrap CEA with f2py to build a python module.

Additional changes to CEA2.f have been made in order to properly handle hydrazine monopropellant’s ammonia dissociation.

# RocketCEA

Contents:

- QuickStart
  - Install Numpy & Matplotlib
  - Install Compiler
  - Install RocketCEA
  - Getting Help
  - Running RocketCEA
  - Test The Install
  - Google Colaboratory
- Install gfortran
  - Debian/Ubuntu
  - CentOS/RHEL
  - OpenSUSE
  - MacOS/OSX
  - Windows 10
- Standard Examples
  - LOX/LH2 Performance
  - Frozen Performance
- Simple Examples
  - N2O4/MMH Performance
  - LOX/LH2 Delta V
- Engine Mixture Ratio
  - Chemical Kinetics
  - LOX/RP1 GG vs SC
  - LOX/LH2 Bulk Density
- Propellant Selection
  - Rough Screening
  - Stage Density
  - Volume Limit
  - Delta V Requirement
  - Mass Limit
  - Monopropellants
- Propellants
  - Special Blends
  - Oxidizers
  - Fuels
  - Monoprop & Solid
- New Propellants
  - New Ox and Fuel
  - New Monoprop
- Plot Examples
  - Cstar Plot
  - Isp Plot
  - Isp Comparisons
- Ambient Isp
  - IspAmb Equation
  - Estimate IspAmb
  - Nozzle Flow Separation
- Hydrazine Monopropellant
  - Chemical Reactions
  - CEA Modification
  - Performance Plot
- Temperature Adjust
  - Standard T and H
  - Changing T and H
- Parasol Example
- RocketCEA Functions
- Copyright
  - License
- Authors
  - Development Lead
  - Patches and Ideas
  - Initial Project Layout
- History
  - GitHub Log
  - PyHatch

# Indices and tables

- Index

- Module Index

- Search Page